# Slack CTTC

[![Join the chat at https://gitter.im/slack_smashbot/Lobby](https://badges.gitter.im/slack_smashbot/Lobby.svg)](https://gitter.im/slack_smashbot/Lobby?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)
Demo slackbot to stash technologies, watch for them, while also
suggesting training. 

[![Build Status](https://travis-ci.org/wray/slack_cttc.svg?branch=master)](https://travis-ci.org/wray/slack_cttc)
